@@ -7,7 +7,7 @@ main()
 	cd -- "$(CDPATH="" cd -- "$(dirname -- "$0")" && pwd)" || exit 2
 
 	# Extend the PATH
-	export PATH=/opt/rakudo/bin/:$HOME/.perl6/bin:$PATH
+	export PATH=/opt/rakudo-pkg/bin/:$HOME/.perl6/bin:$PATH
 
 	# Check what we're going to test
 	case "$TEST" in
